==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d1/d53/structGRFFile.js <==
var structGRFFile =
[
    [ "GRFFile", "d1/d53/structGRFFile.html#a6a2e1b9a8a42624b4832ba4fedef4bef", null ],
    [ "~GRFFile", "d1/d53/structGRFFile.html#a11c41f6d0a5a019ec5c777202f9ada8b", null ],
    [ "GetParam", "d1/d53/structGRFFile.html#a986082c354f1fcc8cc2c70eb916131b4", null ],
    [ "airportspec", "d1/d53/structGRFFile.html#a5da62bb94e760ade1743136a67830f04", null ],
    [ "airtspec", "d1/d53/structGRFFile.html#a898789ce2cdcea8b7222e4180a4d3653", null ],
    [ "canal_local_properties", "d1/d53/structGRFFile.html#a522182d1c3cddc72ccbbbe7ee1bd7eec", null ],
    [ "cargo_list", "d1/d53/structGRFFile.html#afb7e9f49eddb22973ea7cf0a5481c7c6", null ],
    [ "cargo_map", "d1/d53/structGRFFile.html#a5139718cfec7e2996f6de5c53f1b4a68", null ],
    [ "filename", "d1/d53/structGRFFile.html#a40673378c36615efaf6b9cd1f12db8d0", null ],
    [ "grf_features", "d1/d53/structGRFFile.html#a84206c17d154876ea2ba91f6cb5c1933", null ],
    [ "grf_version", "d1/d53/structGRFFile.html#a8197ac91680ec8e9039877773c4c90aa", null ],
    [ "grfid", "d1/d53/structGRFFile.html#a247d429777c98b35121501c5362f6659", null ],
    [ "housespec", "d1/d53/structGRFFile.html#aabb94d76564cb96f0562e9eb4e3dd25b", null ],
    [ "indtspec", "d1/d53/structGRFFile.html#a3b7175023b22e7a8d47889eacf38c40c", null ],
    [ "industryspec", "d1/d53/structGRFFile.html#a10876d0f009927d8829e5f3c3ca02747", null ],
    [ "label", "d1/d53/structGRFFile.html#aae4f86bb8a0a525a4de601901bacfbb4", null ],
    [ "language_map", "d1/d53/structGRFFile.html#ad5d050ccf5b45c51624ae9d328a6942b", null ],
    [ "num_sounds", "d1/d53/structGRFFile.html#a29f5a6fc2b189aebc6af58cbb435fb47", null ],
    [ "objectspec", "d1/d53/structGRFFile.html#ab6abbcbe61cc50927e8eb38b365d0ebf", null ],
    [ "param", "d1/d53/structGRFFile.html#a191ca759d13339776225213e23d2930c", null ],
    [ "param_end", "d1/d53/structGRFFile.html#a03fedf8b0ed764e585bec83c412f99b9", null ],
    [ "price_base_multipliers", "d1/d53/structGRFFile.html#afed6cb1a6a74fa92fe3c94fedc9aaae1", null ],
    [ "railtype_list", "d1/d53/structGRFFile.html#ae81acb684e549a11cd50254d5359385b", null ],
    [ "railtype_map", "d1/d53/structGRFFile.html#ab8e3cadc1dea235d1f9baf0bc4bacab3", null ],
    [ "sound_offset", "d1/d53/structGRFFile.html#aaba1b4cdc9cfedde03717dc75e850316", null ],
    [ "stations", "d1/d53/structGRFFile.html#ac5517a8674e6eb8c989ffaf0490093b3", null ],
    [ "traininfo_vehicle_pitch", "d1/d53/structGRFFile.html#ae393aa10104532d90280fe12ec726343", null ],
    [ "traininfo_vehicle_width", "d1/d53/structGRFFile.html#abd692fe483a254dd4bd31acc94645460", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d1/d53/structGRFFile.js <==
var structGRFFile =
[
    [ "GRFFile", "d1/d53/structGRFFile.html#a6a2e1b9a8a42624b4832ba4fedef4bef", null ],
    [ "~GRFFile", "d1/d53/structGRFFile.html#a11c41f6d0a5a019ec5c777202f9ada8b", null ],
    [ "GetParam", "d1/d53/structGRFFile.html#a986082c354f1fcc8cc2c70eb916131b4", null ],
    [ "airportspec", "d1/d53/structGRFFile.html#a5da62bb94e760ade1743136a67830f04", null ],
    [ "airtspec", "d1/d53/structGRFFile.html#a898789ce2cdcea8b7222e4180a4d3653", null ],
    [ "canal_local_properties", "d1/d53/structGRFFile.html#a522182d1c3cddc72ccbbbe7ee1bd7eec", null ],
    [ "cargo_list", "d1/d53/structGRFFile.html#aa7206606f764eac038a54250bc55c14a", null ],
    [ "cargo_map", "d1/d53/structGRFFile.html#a5139718cfec7e2996f6de5c53f1b4a68", null ],
    [ "filename", "d1/d53/structGRFFile.html#a40673378c36615efaf6b9cd1f12db8d0", null ],
    [ "grf_features", "d1/d53/structGRFFile.html#a84206c17d154876ea2ba91f6cb5c1933", null ],
    [ "grf_version", "d1/d53/structGRFFile.html#a8197ac91680ec8e9039877773c4c90aa", null ],
    [ "grfid", "d1/d53/structGRFFile.html#a247d429777c98b35121501c5362f6659", null ],
    [ "housespec", "d1/d53/structGRFFile.html#aabb94d76564cb96f0562e9eb4e3dd25b", null ],
    [ "indtspec", "d1/d53/structGRFFile.html#a3b7175023b22e7a8d47889eacf38c40c", null ],
    [ "industryspec", "d1/d53/structGRFFile.html#a10876d0f009927d8829e5f3c3ca02747", null ],
    [ "label", "d1/d53/structGRFFile.html#aae4f86bb8a0a525a4de601901bacfbb4", null ],
    [ "language_map", "d1/d53/structGRFFile.html#ad5d050ccf5b45c51624ae9d328a6942b", null ],
    [ "num_sounds", "d1/d53/structGRFFile.html#a29f5a6fc2b189aebc6af58cbb435fb47", null ],
    [ "objectspec", "d1/d53/structGRFFile.html#ab6abbcbe61cc50927e8eb38b365d0ebf", null ],
    [ "param", "d1/d53/structGRFFile.html#a191ca759d13339776225213e23d2930c", null ],
    [ "param_end", "d1/d53/structGRFFile.html#a03fedf8b0ed764e585bec83c412f99b9", null ],
    [ "price_base_multipliers", "d1/d53/structGRFFile.html#afed6cb1a6a74fa92fe3c94fedc9aaae1", null ],
    [ "railtype_list", "d1/d53/structGRFFile.html#a38d52da79da9d37535180d9c69f21787", null ],
    [ "railtype_map", "d1/d53/structGRFFile.html#a307de6ef2c40ec678778f725bc75494d", null ],
    [ "roadtype_list", "d1/d53/structGRFFile.html#a63395d21b8467f2b6d5bb601702cdbf5", null ],
    [ "roadtype_map", "d1/d53/structGRFFile.html#a4fb76b094622eb3822c91cd426da54f8", null ],
    [ "sound_offset", "d1/d53/structGRFFile.html#aaba1b4cdc9cfedde03717dc75e850316", null ],
    [ "stations", "d1/d53/structGRFFile.html#ac5517a8674e6eb8c989ffaf0490093b3", null ],
    [ "traininfo_vehicle_pitch", "d1/d53/structGRFFile.html#ae393aa10104532d90280fe12ec726343", null ],
    [ "traininfo_vehicle_width", "d1/d53/structGRFFile.html#abd692fe483a254dd4bd31acc94645460", null ],
    [ "tramtype_list", "d1/d53/structGRFFile.html#a922193930d35777480564955550cff7c", null ],
    [ "tramtype_map", "d1/d53/structGRFFile.html#a9e84a3399b5bff4d9e13c52522fd63cb", null ]
];
